django\_sorcery.management.commands.sorcery\_heads module
=========================================================

.. automodule:: django_sorcery.management.commands.sorcery_heads
    :members:
    :undoc-members:
    :show-inheritance:
